DynSignatureAlgorithmIdentifier

Trait DynSignatureAlgorithmIdentifier 

pub trait DynSignatureAlgorithmIdentifier {
    // Required method
    fn signature_algorithm_identifier(
        &self,
    ) -> Result<AlgorithmIdentifier<Any>, Error>;
}
Returns AlgorithmIdentifierOwned associated with the signature system.

Unlike AssociatedAlgorithmIdentifier this is intended to be implemented for public and/or private keys.

Required Methods

fn signature_algorithm_identifier( &self, ) -> Result<AlgorithmIdentifier<Any>, Error>

AlgorithmIdentifier for the corresponding signature system.

Errors

Returns errors specific to the concrete type which impls this trait.

Implementors

Source

impl<T> DynSignatureAlgorithmIdentifier for T

Available on crate feature alloc only.